// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: contact.proto

#ifndef GOOGLE_PROTOBUF_INCLUDED_contact_2eproto
#define GOOGLE_PROTOBUF_INCLUDED_contact_2eproto

#include <limits>
#include <string>

#include <google/protobuf/port_def.inc>
#if PROTOBUF_VERSION < 3013000
#error This file was generated by a newer version of protoc which is
#error incompatible with your Protocol Buffer headers. Please update
#error your headers.
#endif
#if 3013000 < PROTOBUF_MIN_PROTOC_VERSION
#error This file was generated by an older version of protoc which is
#error incompatible with your Protocol Buffer headers. Please
#error regenerate this file with a newer version of protoc.
#endif

#include <google/protobuf/port_undef.inc>
#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/arena.h>
#include <google/protobuf/arenastring.h>
#include <google/protobuf/generated_message_table_driven.h>
#include <google/protobuf/generated_message_util.h>
#include <google/protobuf/inlined_string_field.h>
#include <google/protobuf/metadata_lite.h>
#include <google/protobuf/generated_message_reflection.h>
#include <google/protobuf/message.h>
#include <google/protobuf/repeated_field.h>  // IWYU pragma: export
#include <google/protobuf/extension_set.h>  // IWYU pragma: export
#include <google/protobuf/unknown_field_set.h>
#include "vector3d.pb.h"
#include "time.pb.h"
#include "joint_wrench.pb.h"
#ifndef _MSC_VER
#pragma GCC system_header
#pragma GCC diagnostic ignored "-Wshadow"
#pragma GCC diagnostic ignored "-Wunused-parameter"
#endif
#include <boost/shared_ptr.hpp>
#include <gazebo/util/system.hh>
#include "gazebo/msgs/MsgFactory.hh"
// @@protoc_insertion_point(includes)
#include <google/protobuf/port_def.inc>
#define PROTOBUF_INTERNAL_EXPORT_contact_2eproto GZ_MSGS_VISIBLE
PROTOBUF_NAMESPACE_OPEN
namespace internal {
class AnyMetadata;
}  // namespace internal
PROTOBUF_NAMESPACE_CLOSE

// Internal implementation detail -- do not use these members.
struct GZ_MSGS_VISIBLE TableStruct_contact_2eproto {
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTableField entries[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::AuxiliaryParseTableField aux[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTable schema[1]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::FieldMetadata field_metadata[];
  static const ::PROTOBUF_NAMESPACE_ID::internal::SerializationTable serialization_table[];
  static const ::PROTOBUF_NAMESPACE_ID::uint32 offsets[];
};
extern GZ_MSGS_VISIBLE const ::PROTOBUF_NAMESPACE_ID::internal::DescriptorTable descriptor_table_contact_2eproto;
namespace gazebo {
namespace msgs {
class Contact;
class ContactDefaultTypeInternal;
GZ_MSGS_VISIBLE extern ContactDefaultTypeInternal _Contact_default_instance_;
}  // namespace msgs
}  // namespace gazebo
PROTOBUF_NAMESPACE_OPEN
template<> GZ_MSGS_VISIBLE ::gazebo::msgs::Contact* Arena::CreateMaybeMessage<::gazebo::msgs::Contact>(Arena*);
PROTOBUF_NAMESPACE_CLOSE
namespace gazebo {
namespace msgs {

// ===================================================================

class GZ_MSGS_VISIBLE Contact PROTOBUF_FINAL :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:gazebo.msgs.Contact) */ {
 public:
  inline Contact() : Contact(nullptr) {}
  virtual ~Contact();

  Contact(const Contact& from);
  Contact(Contact&& from) noexcept
    : Contact() {
    *this = ::std::move(from);
  }

  inline Contact& operator=(const Contact& from) {
    CopyFrom(from);
    return *this;
  }
  inline Contact& operator=(Contact&& from) noexcept {
    if (GetArena() == from.GetArena()) {
      if (this != &from) InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet& unknown_fields() const {
    return _internal_metadata_.unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(::PROTOBUF_NAMESPACE_ID::UnknownFieldSet::default_instance);
  }
  inline ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet* mutable_unknown_fields() {
    return _internal_metadata_.mutable_unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>();
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return GetMetadataStatic().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return GetMetadataStatic().reflection;
  }
  static const Contact& default_instance();

  static void InitAsDefaultInstance();  // FOR INTERNAL USE ONLY
  static inline const Contact* internal_default_instance() {
    return reinterpret_cast<const Contact*>(
               &_Contact_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    0;

  friend void swap(Contact& a, Contact& b) {
    a.Swap(&b);
  }
  inline void Swap(Contact* other) {
    if (other == this) return;
    if (GetArena() == other->GetArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(Contact* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline Contact* New() const final {
    return CreateMaybeMessage<Contact>(nullptr);
  }

  Contact* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<Contact>(arena);
  }
  void CopyFrom(const ::PROTOBUF_NAMESPACE_ID::Message& from) final;
  void MergeFrom(const ::PROTOBUF_NAMESPACE_ID::Message& from) final;
  void CopyFrom(const Contact& from);
  void MergeFrom(const Contact& from);
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  inline void SharedCtor();
  inline void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(Contact* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "gazebo.msgs.Contact";
  }
  protected:
  explicit Contact(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;
  private:
  static ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadataStatic() {
    ::PROTOBUF_NAMESPACE_ID::internal::AssignDescriptors(&::descriptor_table_contact_2eproto);
    return ::descriptor_table_contact_2eproto.file_level_metadata[kIndexInFileMessages];
  }

  public:

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  enum : int {
    kPositionFieldNumber = 3,
    kNormalFieldNumber = 4,
    kDepthFieldNumber = 5,
    kWrenchFieldNumber = 6,
    kCollision1FieldNumber = 1,
    kCollision2FieldNumber = 2,
    kWorldFieldNumber = 8,
    kTimeFieldNumber = 7,
  };
  // repeated .gazebo.msgs.Vector3d position = 3;
  int position_size() const;
  private:
  int _internal_position_size() const;
  public:
  void clear_position();
  ::gazebo::msgs::Vector3d* mutable_position(int index);
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::gazebo::msgs::Vector3d >*
      mutable_position();
  private:
  const ::gazebo::msgs::Vector3d& _internal_position(int index) const;
  ::gazebo::msgs::Vector3d* _internal_add_position();
  public:
  const ::gazebo::msgs::Vector3d& position(int index) const;
  ::gazebo::msgs::Vector3d* add_position();
  const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::gazebo::msgs::Vector3d >&
      position() const;

  // repeated .gazebo.msgs.Vector3d normal = 4;
  int normal_size() const;
  private:
  int _internal_normal_size() const;
  public:
  void clear_normal();
  ::gazebo::msgs::Vector3d* mutable_normal(int index);
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::gazebo::msgs::Vector3d >*
      mutable_normal();
  private:
  const ::gazebo::msgs::Vector3d& _internal_normal(int index) const;
  ::gazebo::msgs::Vector3d* _internal_add_normal();
  public:
  const ::gazebo::msgs::Vector3d& normal(int index) const;
  ::gazebo::msgs::Vector3d* add_normal();
  const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::gazebo::msgs::Vector3d >&
      normal() const;

  // repeated double depth = 5;
  int depth_size() const;
  private:
  int _internal_depth_size() const;
  public:
  void clear_depth();
  private:
  double _internal_depth(int index) const;
  const ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >&
      _internal_depth() const;
  void _internal_add_depth(double value);
  ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >*
      _internal_mutable_depth();
  public:
  double depth(int index) const;
  void set_depth(int index, double value);
  void add_depth(double value);
  const ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >&
      depth() const;
  ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >*
      mutable_depth();

  // repeated .gazebo.msgs.JointWrench wrench = 6;
  int wrench_size() const;
  private:
  int _internal_wrench_size() const;
  public:
  void clear_wrench();
  ::gazebo::msgs::JointWrench* mutable_wrench(int index);
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::gazebo::msgs::JointWrench >*
      mutable_wrench();
  private:
  const ::gazebo::msgs::JointWrench& _internal_wrench(int index) const;
  ::gazebo::msgs::JointWrench* _internal_add_wrench();
  public:
  const ::gazebo::msgs::JointWrench& wrench(int index) const;
  ::gazebo::msgs::JointWrench* add_wrench();
  const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::gazebo::msgs::JointWrench >&
      wrench() const;

  // required string collision1 = 1;
  bool has_collision1() const;
  private:
  bool _internal_has_collision1() const;
  public:
  void clear_collision1();
  const std::string& collision1() const;
  void set_collision1(const std::string& value);
  void set_collision1(std::string&& value);
  void set_collision1(const char* value);
  void set_collision1(const char* value, size_t size);
  std::string* mutable_collision1();
  std::string* release_collision1();
  void set_allocated_collision1(std::string* collision1);
  private:
  const std::string& _internal_collision1() const;
  void _internal_set_collision1(const std::string& value);
  std::string* _internal_mutable_collision1();
  public:

  // required string collision2 = 2;
  bool has_collision2() const;
  private:
  bool _internal_has_collision2() const;
  public:
  void clear_collision2();
  const std::string& collision2() const;
  void set_collision2(const std::string& value);
  void set_collision2(std::string&& value);
  void set_collision2(const char* value);
  void set_collision2(const char* value, size_t size);
  std::string* mutable_collision2();
  std::string* release_collision2();
  void set_allocated_collision2(std::string* collision2);
  private:
  const std::string& _internal_collision2() const;
  void _internal_set_collision2(const std::string& value);
  std::string* _internal_mutable_collision2();
  public:

  // required string world = 8;
  bool has_world() const;
  private:
  bool _internal_has_world() const;
  public:
  void clear_world();
  const std::string& world() const;
  void set_world(const std::string& value);
  void set_world(std::string&& value);
  void set_world(const char* value);
  void set_world(const char* value, size_t size);
  std::string* mutable_world();
  std::string* release_world();
  void set_allocated_world(std::string* world);
  private:
  const std::string& _internal_world() const;
  void _internal_set_world(const std::string& value);
  std::string* _internal_mutable_world();
  public:

  // required .gazebo.msgs.Time time = 7;
  bool has_time() const;
  private:
  bool _internal_has_time() const;
  public:
  void clear_time();
  const ::gazebo::msgs::Time& time() const;
  ::gazebo::msgs::Time* release_time();
  ::gazebo::msgs::Time* mutable_time();
  void set_allocated_time(::gazebo::msgs::Time* time);
  private:
  const ::gazebo::msgs::Time& _internal_time() const;
  ::gazebo::msgs::Time* _internal_mutable_time();
  public:
  void unsafe_arena_set_allocated_time(
      ::gazebo::msgs::Time* time);
  ::gazebo::msgs::Time* unsafe_arena_release_time();

  // @@protoc_insertion_point(class_scope:gazebo.msgs.Contact)
 private:
  class _Internal;

  // helper for ByteSizeLong()
  size_t RequiredFieldsByteSizeFallback() const;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::internal::HasBits<1> _has_bits_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::gazebo::msgs::Vector3d > position_;
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::gazebo::msgs::Vector3d > normal_;
  ::PROTOBUF_NAMESPACE_ID::RepeatedField< double > depth_;
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::gazebo::msgs::JointWrench > wrench_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr collision1_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr collision2_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr world_;
  ::gazebo::msgs::Time* time_;
  friend struct ::TableStruct_contact_2eproto;
};
// ===================================================================


// ===================================================================

#ifdef __GNUC__
  #pragma GCC diagnostic push
  #pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// Contact

// required string collision1 = 1;
inline bool Contact::_internal_has_collision1() const {
  bool value = (_has_bits_[0] & 0x00000001u) != 0;
  return value;
}
inline bool Contact::has_collision1() const {
  return _internal_has_collision1();
}
inline void Contact::clear_collision1() {
  collision1_.ClearToEmpty(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArena());
  _has_bits_[0] &= ~0x00000001u;
}
inline const std::string& Contact::collision1() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.Contact.collision1)
  return _internal_collision1();
}
inline void Contact::set_collision1(const std::string& value) {
  _internal_set_collision1(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.Contact.collision1)
}
inline std::string* Contact::mutable_collision1() {
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.Contact.collision1)
  return _internal_mutable_collision1();
}
inline const std::string& Contact::_internal_collision1() const {
  return collision1_.Get();
}
inline void Contact::_internal_set_collision1(const std::string& value) {
  _has_bits_[0] |= 0x00000001u;
  collision1_.Set(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), value, GetArena());
}
inline void Contact::set_collision1(std::string&& value) {
  _has_bits_[0] |= 0x00000001u;
  collision1_.Set(
    &::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), ::std::move(value), GetArena());
  // @@protoc_insertion_point(field_set_rvalue:gazebo.msgs.Contact.collision1)
}
inline void Contact::set_collision1(const char* value) {
  GOOGLE_DCHECK(value != nullptr);
  _has_bits_[0] |= 0x00000001u;
  collision1_.Set(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), ::std::string(value),
              GetArena());
  // @@protoc_insertion_point(field_set_char:gazebo.msgs.Contact.collision1)
}
inline void Contact::set_collision1(const char* value,
    size_t size) {
  _has_bits_[0] |= 0x00000001u;
  collision1_.Set(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), ::std::string(
      reinterpret_cast<const char*>(value), size), GetArena());
  // @@protoc_insertion_point(field_set_pointer:gazebo.msgs.Contact.collision1)
}
inline std::string* Contact::_internal_mutable_collision1() {
  _has_bits_[0] |= 0x00000001u;
  return collision1_.Mutable(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArena());
}
inline std::string* Contact::release_collision1() {
  // @@protoc_insertion_point(field_release:gazebo.msgs.Contact.collision1)
  if (!_internal_has_collision1()) {
    return nullptr;
  }
  _has_bits_[0] &= ~0x00000001u;
  return collision1_.ReleaseNonDefault(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArena());
}
inline void Contact::set_allocated_collision1(std::string* collision1) {
  if (collision1 != nullptr) {
    _has_bits_[0] |= 0x00000001u;
  } else {
    _has_bits_[0] &= ~0x00000001u;
  }
  collision1_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), collision1,
      GetArena());
  // @@protoc_insertion_point(field_set_allocated:gazebo.msgs.Contact.collision1)
}

// required string collision2 = 2;
inline bool Contact::_internal_has_collision2() const {
  bool value = (_has_bits_[0] & 0x00000002u) != 0;
  return value;
}
inline bool Contact::has_collision2() const {
  return _internal_has_collision2();
}
inline void Contact::clear_collision2() {
  collision2_.ClearToEmpty(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArena());
  _has_bits_[0] &= ~0x00000002u;
}
inline const std::string& Contact::collision2() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.Contact.collision2)
  return _internal_collision2();
}
inline void Contact::set_collision2(const std::string& value) {
  _internal_set_collision2(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.Contact.collision2)
}
inline std::string* Contact::mutable_collision2() {
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.Contact.collision2)
  return _internal_mutable_collision2();
}
inline const std::string& Contact::_internal_collision2() const {
  return collision2_.Get();
}
inline void Contact::_internal_set_collision2(const std::string& value) {
  _has_bits_[0] |= 0x00000002u;
  collision2_.Set(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), value, GetArena());
}
inline void Contact::set_collision2(std::string&& value) {
  _has_bits_[0] |= 0x00000002u;
  collision2_.Set(
    &::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), ::std::move(value), GetArena());
  // @@protoc_insertion_point(field_set_rvalue:gazebo.msgs.Contact.collision2)
}
inline void Contact::set_collision2(const char* value) {
  GOOGLE_DCHECK(value != nullptr);
  _has_bits_[0] |= 0x00000002u;
  collision2_.Set(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), ::std::string(value),
              GetArena());
  // @@protoc_insertion_point(field_set_char:gazebo.msgs.Contact.collision2)
}
inline void Contact::set_collision2(const char* value,
    size_t size) {
  _has_bits_[0] |= 0x00000002u;
  collision2_.Set(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), ::std::string(
      reinterpret_cast<const char*>(value), size), GetArena());
  // @@protoc_insertion_point(field_set_pointer:gazebo.msgs.Contact.collision2)
}
inline std::string* Contact::_internal_mutable_collision2() {
  _has_bits_[0] |= 0x00000002u;
  return collision2_.Mutable(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArena());
}
inline std::string* Contact::release_collision2() {
  // @@protoc_insertion_point(field_release:gazebo.msgs.Contact.collision2)
  if (!_internal_has_collision2()) {
    return nullptr;
  }
  _has_bits_[0] &= ~0x00000002u;
  return collision2_.ReleaseNonDefault(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArena());
}
inline void Contact::set_allocated_collision2(std::string* collision2) {
  if (collision2 != nullptr) {
    _has_bits_[0] |= 0x00000002u;
  } else {
    _has_bits_[0] &= ~0x00000002u;
  }
  collision2_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), collision2,
      GetArena());
  // @@protoc_insertion_point(field_set_allocated:gazebo.msgs.Contact.collision2)
}

// repeated .gazebo.msgs.Vector3d position = 3;
inline int Contact::_internal_position_size() const {
  return position_.size();
}
inline int Contact::position_size() const {
  return _internal_position_size();
}
inline ::gazebo::msgs::Vector3d* Contact::mutable_position(int index) {
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.Contact.position)
  return position_.Mutable(index);
}
inline ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::gazebo::msgs::Vector3d >*
Contact::mutable_position() {
  // @@protoc_insertion_point(field_mutable_list:gazebo.msgs.Contact.position)
  return &position_;
}
inline const ::gazebo::msgs::Vector3d& Contact::_internal_position(int index) const {
  return position_.Get(index);
}
inline const ::gazebo::msgs::Vector3d& Contact::position(int index) const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.Contact.position)
  return _internal_position(index);
}
inline ::gazebo::msgs::Vector3d* Contact::_internal_add_position() {
  return position_.Add();
}
inline ::gazebo::msgs::Vector3d* Contact::add_position() {
  // @@protoc_insertion_point(field_add:gazebo.msgs.Contact.position)
  return _internal_add_position();
}
inline const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::gazebo::msgs::Vector3d >&
Contact::position() const {
  // @@protoc_insertion_point(field_list:gazebo.msgs.Contact.position)
  return position_;
}

// repeated .gazebo.msgs.Vector3d normal = 4;
inline int Contact::_internal_normal_size() const {
  return normal_.size();
}
inline int Contact::normal_size() const {
  return _internal_normal_size();
}
inline ::gazebo::msgs::Vector3d* Contact::mutable_normal(int index) {
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.Contact.normal)
  return normal_.Mutable(index);
}
inline ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::gazebo::msgs::Vector3d >*
Contact::mutable_normal() {
  // @@protoc_insertion_point(field_mutable_list:gazebo.msgs.Contact.normal)
  return &normal_;
}
inline const ::gazebo::msgs::Vector3d& Contact::_internal_normal(int index) const {
  return normal_.Get(index);
}
inline const ::gazebo::msgs::Vector3d& Contact::normal(int index) const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.Contact.normal)
  return _internal_normal(index);
}
inline ::gazebo::msgs::Vector3d* Contact::_internal_add_normal() {
  return normal_.Add();
}
inline ::gazebo::msgs::Vector3d* Contact::add_normal() {
  // @@protoc_insertion_point(field_add:gazebo.msgs.Contact.normal)
  return _internal_add_normal();
}
inline const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::gazebo::msgs::Vector3d >&
Contact::normal() const {
  // @@protoc_insertion_point(field_list:gazebo.msgs.Contact.normal)
  return normal_;
}

// repeated double depth = 5;
inline int Contact::_internal_depth_size() const {
  return depth_.size();
}
inline int Contact::depth_size() const {
  return _internal_depth_size();
}
inline void Contact::clear_depth() {
  depth_.Clear();
}
inline double Contact::_internal_depth(int index) const {
  return depth_.Get(index);
}
inline double Contact::depth(int index) const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.Contact.depth)
  return _internal_depth(index);
}
inline void Contact::set_depth(int index, double value) {
  depth_.Set(index, value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.Contact.depth)
}
inline void Contact::_internal_add_depth(double value) {
  depth_.Add(value);
}
inline void Contact::add_depth(double value) {
  _internal_add_depth(value);
  // @@protoc_insertion_point(field_add:gazebo.msgs.Contact.depth)
}
inline const ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >&
Contact::_internal_depth() const {
  return depth_;
}
inline const ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >&
Contact::depth() const {
  // @@protoc_insertion_point(field_list:gazebo.msgs.Contact.depth)
  return _internal_depth();
}
inline ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >*
Contact::_internal_mutable_depth() {
  return &depth_;
}
inline ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >*
Contact::mutable_depth() {
  // @@protoc_insertion_point(field_mutable_list:gazebo.msgs.Contact.depth)
  return _internal_mutable_depth();
}

// repeated .gazebo.msgs.JointWrench wrench = 6;
inline int Contact::_internal_wrench_size() const {
  return wrench_.size();
}
inline int Contact::wrench_size() const {
  return _internal_wrench_size();
}
inline ::gazebo::msgs::JointWrench* Contact::mutable_wrench(int index) {
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.Contact.wrench)
  return wrench_.Mutable(index);
}
inline ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::gazebo::msgs::JointWrench >*
Contact::mutable_wrench() {
  // @@protoc_insertion_point(field_mutable_list:gazebo.msgs.Contact.wrench)
  return &wrench_;
}
inline const ::gazebo::msgs::JointWrench& Contact::_internal_wrench(int index) const {
  return wrench_.Get(index);
}
inline const ::gazebo::msgs::JointWrench& Contact::wrench(int index) const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.Contact.wrench)
  return _internal_wrench(index);
}
inline ::gazebo::msgs::JointWrench* Contact::_internal_add_wrench() {
  return wrench_.Add();
}
inline ::gazebo::msgs::JointWrench* Contact::add_wrench() {
  // @@protoc_insertion_point(field_add:gazebo.msgs.Contact.wrench)
  return _internal_add_wrench();
}
inline const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::gazebo::msgs::JointWrench >&
Contact::wrench() const {
  // @@protoc_insertion_point(field_list:gazebo.msgs.Contact.wrench)
  return wrench_;
}

// required .gazebo.msgs.Time time = 7;
inline bool Contact::_internal_has_time() const {
  bool value = (_has_bits_[0] & 0x00000008u) != 0;
  PROTOBUF_ASSUME(!value || time_ != nullptr);
  return value;
}
inline bool Contact::has_time() const {
  return _internal_has_time();
}
inline const ::gazebo::msgs::Time& Contact::_internal_time() const {
  const ::gazebo::msgs::Time* p = time_;
  return p != nullptr ? *p : *reinterpret_cast<const ::gazebo::msgs::Time*>(
      &::gazebo::msgs::_Time_default_instance_);
}
inline const ::gazebo::msgs::Time& Contact::time() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.Contact.time)
  return _internal_time();
}
inline void Contact::unsafe_arena_set_allocated_time(
    ::gazebo::msgs::Time* time) {
  if (GetArena() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(time_);
  }
  time_ = time;
  if (time) {
    _has_bits_[0] |= 0x00000008u;
  } else {
    _has_bits_[0] &= ~0x00000008u;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:gazebo.msgs.Contact.time)
}
inline ::gazebo::msgs::Time* Contact::release_time() {
  _has_bits_[0] &= ~0x00000008u;
  ::gazebo::msgs::Time* temp = time_;
  time_ = nullptr;
  if (GetArena() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
  return temp;
}
inline ::gazebo::msgs::Time* Contact::unsafe_arena_release_time() {
  // @@protoc_insertion_point(field_release:gazebo.msgs.Contact.time)
  _has_bits_[0] &= ~0x00000008u;
  ::gazebo::msgs::Time* temp = time_;
  time_ = nullptr;
  return temp;
}
inline ::gazebo::msgs::Time* Contact::_internal_mutable_time() {
  _has_bits_[0] |= 0x00000008u;
  if (time_ == nullptr) {
    auto* p = CreateMaybeMessage<::gazebo::msgs::Time>(GetArena());
    time_ = p;
  }
  return time_;
}
inline ::gazebo::msgs::Time* Contact::mutable_time() {
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.Contact.time)
  return _internal_mutable_time();
}
inline void Contact::set_allocated_time(::gazebo::msgs::Time* time) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArena();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(time_);
  }
  if (time) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
      reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(time)->GetArena();
    if (message_arena != submessage_arena) {
      time = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, time, submessage_arena);
    }
    _has_bits_[0] |= 0x00000008u;
  } else {
    _has_bits_[0] &= ~0x00000008u;
  }
  time_ = time;
  // @@protoc_insertion_point(field_set_allocated:gazebo.msgs.Contact.time)
}

// required string world = 8;
inline bool Contact::_internal_has_world() const {
  bool value = (_has_bits_[0] & 0x00000004u) != 0;
  return value;
}
inline bool Contact::has_world() const {
  return _internal_has_world();
}
inline void Contact::clear_world() {
  world_.ClearToEmpty(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArena());
  _has_bits_[0] &= ~0x00000004u;
}
inline const std::string& Contact::world() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.Contact.world)
  return _internal_world();
}
inline void Contact::set_world(const std::string& value) {
  _internal_set_world(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.Contact.world)
}
inline std::string* Contact::mutable_world() {
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.Contact.world)
  return _internal_mutable_world();
}
inline const std::string& Contact::_internal_world() const {
  return world_.Get();
}
inline void Contact::_internal_set_world(const std::string& value) {
  _has_bits_[0] |= 0x00000004u;
  world_.Set(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), value, GetArena());
}
inline void Contact::set_world(std::string&& value) {
  _has_bits_[0] |= 0x00000004u;
  world_.Set(
    &::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), ::std::move(value), GetArena());
  // @@protoc_insertion_point(field_set_rvalue:gazebo.msgs.Contact.world)
}
inline void Contact::set_world(const char* value) {
  GOOGLE_DCHECK(value != nullptr);
  _has_bits_[0] |= 0x00000004u;
  world_.Set(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), ::std::string(value),
              GetArena());
  // @@protoc_insertion_point(field_set_char:gazebo.msgs.Contact.world)
}
inline void Contact::set_world(const char* value,
    size_t size) {
  _has_bits_[0] |= 0x00000004u;
  world_.Set(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), ::std::string(
      reinterpret_cast<const char*>(value), size), GetArena());
  // @@protoc_insertion_point(field_set_pointer:gazebo.msgs.Contact.world)
}
inline std::string* Contact::_internal_mutable_world() {
  _has_bits_[0] |= 0x00000004u;
  return world_.Mutable(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArena());
}
inline std::string* Contact::release_world() {
  // @@protoc_insertion_point(field_release:gazebo.msgs.Contact.world)
  if (!_internal_has_world()) {
    return nullptr;
  }
  _has_bits_[0] &= ~0x00000004u;
  return world_.ReleaseNonDefault(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArena());
}
inline void Contact::set_allocated_world(std::string* world) {
  if (world != nullptr) {
    _has_bits_[0] |= 0x00000004u;
  } else {
    _has_bits_[0] &= ~0x00000004u;
  }
  world_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), world,
      GetArena());
  // @@protoc_insertion_point(field_set_allocated:gazebo.msgs.Contact.world)
}

#ifdef __GNUC__
  #pragma GCC diagnostic pop
#endif  // __GNUC__

typedef boost::shared_ptr<gazebo::msgs::Contact> ContactPtr;
// @@protoc_insertion_point(namespace_scope)

}  // namespace msgs
}  // namespace gazebo

typedef const boost::shared_ptr<gazebo::msgs::Contact const> ConstContactPtr;
// @@protoc_insertion_point(global_scope)

#include <google/protobuf/port_undef.inc>
#endif  // GOOGLE_PROTOBUF_INCLUDED_GOOGLE_PROTOBUF_INCLUDED_contact_2eproto
