// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: wrench.proto

#ifndef GOOGLE_PROTOBUF_INCLUDED_wrench_2eproto
#define GOOGLE_PROTOBUF_INCLUDED_wrench_2eproto

#include <limits>
#include <string>

#include <google/protobuf/port_def.inc>
#if PROTOBUF_VERSION < 3013000
#error This file was generated by a newer version of protoc which is
#error incompatible with your Protocol Buffer headers. Please update
#error your headers.
#endif
#if 3013000 < PROTOBUF_MIN_PROTOC_VERSION
#error This file was generated by an older version of protoc which is
#error incompatible with your Protocol Buffer headers. Please
#error regenerate this file with a newer version of protoc.
#endif

#include <google/protobuf/port_undef.inc>
#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/arena.h>
#include <google/protobuf/arenastring.h>
#include <google/protobuf/generated_message_table_driven.h>
#include <google/protobuf/generated_message_util.h>
#include <google/protobuf/inlined_string_field.h>
#include <google/protobuf/metadata_lite.h>
#include <google/protobuf/generated_message_reflection.h>
#include <google/protobuf/message.h>
#include <google/protobuf/repeated_field.h>  // IWYU pragma: export
#include <google/protobuf/extension_set.h>  // IWYU pragma: export
#include <google/protobuf/unknown_field_set.h>
#include "vector3d.pb.h"
#ifndef _MSC_VER
#pragma GCC system_header
#pragma GCC diagnostic ignored "-Wshadow"
#pragma GCC diagnostic ignored "-Wunused-parameter"
#endif
#include <boost/shared_ptr.hpp>
#include <gazebo/util/system.hh>
#include "gazebo/msgs/MsgFactory.hh"
// @@protoc_insertion_point(includes)
#include <google/protobuf/port_def.inc>
#define PROTOBUF_INTERNAL_EXPORT_wrench_2eproto GZ_MSGS_VISIBLE
PROTOBUF_NAMESPACE_OPEN
namespace internal {
class AnyMetadata;
}  // namespace internal
PROTOBUF_NAMESPACE_CLOSE

// Internal implementation detail -- do not use these members.
struct GZ_MSGS_VISIBLE TableStruct_wrench_2eproto {
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTableField entries[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::AuxiliaryParseTableField aux[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTable schema[1]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::FieldMetadata field_metadata[];
  static const ::PROTOBUF_NAMESPACE_ID::internal::SerializationTable serialization_table[];
  static const ::PROTOBUF_NAMESPACE_ID::uint32 offsets[];
};
extern GZ_MSGS_VISIBLE const ::PROTOBUF_NAMESPACE_ID::internal::DescriptorTable descriptor_table_wrench_2eproto;
namespace gazebo {
namespace msgs {
class Wrench;
class WrenchDefaultTypeInternal;
GZ_MSGS_VISIBLE extern WrenchDefaultTypeInternal _Wrench_default_instance_;
}  // namespace msgs
}  // namespace gazebo
PROTOBUF_NAMESPACE_OPEN
template<> GZ_MSGS_VISIBLE ::gazebo::msgs::Wrench* Arena::CreateMaybeMessage<::gazebo::msgs::Wrench>(Arena*);
PROTOBUF_NAMESPACE_CLOSE
namespace gazebo {
namespace msgs {

// ===================================================================

class GZ_MSGS_VISIBLE Wrench PROTOBUF_FINAL :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:gazebo.msgs.Wrench) */ {
 public:
  inline Wrench() : Wrench(nullptr) {}
  virtual ~Wrench();

  Wrench(const Wrench& from);
  Wrench(Wrench&& from) noexcept
    : Wrench() {
    *this = ::std::move(from);
  }

  inline Wrench& operator=(const Wrench& from) {
    CopyFrom(from);
    return *this;
  }
  inline Wrench& operator=(Wrench&& from) noexcept {
    if (GetArena() == from.GetArena()) {
      if (this != &from) InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet& unknown_fields() const {
    return _internal_metadata_.unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(::PROTOBUF_NAMESPACE_ID::UnknownFieldSet::default_instance);
  }
  inline ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet* mutable_unknown_fields() {
    return _internal_metadata_.mutable_unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>();
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return GetMetadataStatic().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return GetMetadataStatic().reflection;
  }
  static const Wrench& default_instance();

  static void InitAsDefaultInstance();  // FOR INTERNAL USE ONLY
  static inline const Wrench* internal_default_instance() {
    return reinterpret_cast<const Wrench*>(
               &_Wrench_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    0;

  friend void swap(Wrench& a, Wrench& b) {
    a.Swap(&b);
  }
  inline void Swap(Wrench* other) {
    if (other == this) return;
    if (GetArena() == other->GetArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(Wrench* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline Wrench* New() const final {
    return CreateMaybeMessage<Wrench>(nullptr);
  }

  Wrench* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<Wrench>(arena);
  }
  void CopyFrom(const ::PROTOBUF_NAMESPACE_ID::Message& from) final;
  void MergeFrom(const ::PROTOBUF_NAMESPACE_ID::Message& from) final;
  void CopyFrom(const Wrench& from);
  void MergeFrom(const Wrench& from);
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  inline void SharedCtor();
  inline void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(Wrench* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "gazebo.msgs.Wrench";
  }
  protected:
  explicit Wrench(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;
  private:
  static ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadataStatic() {
    ::PROTOBUF_NAMESPACE_ID::internal::AssignDescriptors(&::descriptor_table_wrench_2eproto);
    return ::descriptor_table_wrench_2eproto.file_level_metadata[kIndexInFileMessages];
  }

  public:

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  enum : int {
    kForceFieldNumber = 1,
    kTorqueFieldNumber = 2,
    kForceOffsetFieldNumber = 3,
  };
  // required .gazebo.msgs.Vector3d force = 1;
  bool has_force() const;
  private:
  bool _internal_has_force() const;
  public:
  void clear_force();
  const ::gazebo::msgs::Vector3d& force() const;
  ::gazebo::msgs::Vector3d* release_force();
  ::gazebo::msgs::Vector3d* mutable_force();
  void set_allocated_force(::gazebo::msgs::Vector3d* force);
  private:
  const ::gazebo::msgs::Vector3d& _internal_force() const;
  ::gazebo::msgs::Vector3d* _internal_mutable_force();
  public:
  void unsafe_arena_set_allocated_force(
      ::gazebo::msgs::Vector3d* force);
  ::gazebo::msgs::Vector3d* unsafe_arena_release_force();

  // required .gazebo.msgs.Vector3d torque = 2;
  bool has_torque() const;
  private:
  bool _internal_has_torque() const;
  public:
  void clear_torque();
  const ::gazebo::msgs::Vector3d& torque() const;
  ::gazebo::msgs::Vector3d* release_torque();
  ::gazebo::msgs::Vector3d* mutable_torque();
  void set_allocated_torque(::gazebo::msgs::Vector3d* torque);
  private:
  const ::gazebo::msgs::Vector3d& _internal_torque() const;
  ::gazebo::msgs::Vector3d* _internal_mutable_torque();
  public:
  void unsafe_arena_set_allocated_torque(
      ::gazebo::msgs::Vector3d* torque);
  ::gazebo::msgs::Vector3d* unsafe_arena_release_torque();

  // optional .gazebo.msgs.Vector3d force_offset = 3;
  bool has_force_offset() const;
  private:
  bool _internal_has_force_offset() const;
  public:
  void clear_force_offset();
  const ::gazebo::msgs::Vector3d& force_offset() const;
  ::gazebo::msgs::Vector3d* release_force_offset();
  ::gazebo::msgs::Vector3d* mutable_force_offset();
  void set_allocated_force_offset(::gazebo::msgs::Vector3d* force_offset);
  private:
  const ::gazebo::msgs::Vector3d& _internal_force_offset() const;
  ::gazebo::msgs::Vector3d* _internal_mutable_force_offset();
  public:
  void unsafe_arena_set_allocated_force_offset(
      ::gazebo::msgs::Vector3d* force_offset);
  ::gazebo::msgs::Vector3d* unsafe_arena_release_force_offset();

  // @@protoc_insertion_point(class_scope:gazebo.msgs.Wrench)
 private:
  class _Internal;

  // helper for ByteSizeLong()
  size_t RequiredFieldsByteSizeFallback() const;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::internal::HasBits<1> _has_bits_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  ::gazebo::msgs::Vector3d* force_;
  ::gazebo::msgs::Vector3d* torque_;
  ::gazebo::msgs::Vector3d* force_offset_;
  friend struct ::TableStruct_wrench_2eproto;
};
// ===================================================================


// ===================================================================

#ifdef __GNUC__
  #pragma GCC diagnostic push
  #pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// Wrench

// required .gazebo.msgs.Vector3d force = 1;
inline bool Wrench::_internal_has_force() const {
  bool value = (_has_bits_[0] & 0x00000001u) != 0;
  PROTOBUF_ASSUME(!value || force_ != nullptr);
  return value;
}
inline bool Wrench::has_force() const {
  return _internal_has_force();
}
inline const ::gazebo::msgs::Vector3d& Wrench::_internal_force() const {
  const ::gazebo::msgs::Vector3d* p = force_;
  return p != nullptr ? *p : *reinterpret_cast<const ::gazebo::msgs::Vector3d*>(
      &::gazebo::msgs::_Vector3d_default_instance_);
}
inline const ::gazebo::msgs::Vector3d& Wrench::force() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.Wrench.force)
  return _internal_force();
}
inline void Wrench::unsafe_arena_set_allocated_force(
    ::gazebo::msgs::Vector3d* force) {
  if (GetArena() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(force_);
  }
  force_ = force;
  if (force) {
    _has_bits_[0] |= 0x00000001u;
  } else {
    _has_bits_[0] &= ~0x00000001u;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:gazebo.msgs.Wrench.force)
}
inline ::gazebo::msgs::Vector3d* Wrench::release_force() {
  _has_bits_[0] &= ~0x00000001u;
  ::gazebo::msgs::Vector3d* temp = force_;
  force_ = nullptr;
  if (GetArena() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
  return temp;
}
inline ::gazebo::msgs::Vector3d* Wrench::unsafe_arena_release_force() {
  // @@protoc_insertion_point(field_release:gazebo.msgs.Wrench.force)
  _has_bits_[0] &= ~0x00000001u;
  ::gazebo::msgs::Vector3d* temp = force_;
  force_ = nullptr;
  return temp;
}
inline ::gazebo::msgs::Vector3d* Wrench::_internal_mutable_force() {
  _has_bits_[0] |= 0x00000001u;
  if (force_ == nullptr) {
    auto* p = CreateMaybeMessage<::gazebo::msgs::Vector3d>(GetArena());
    force_ = p;
  }
  return force_;
}
inline ::gazebo::msgs::Vector3d* Wrench::mutable_force() {
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.Wrench.force)
  return _internal_mutable_force();
}
inline void Wrench::set_allocated_force(::gazebo::msgs::Vector3d* force) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArena();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(force_);
  }
  if (force) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
      reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(force)->GetArena();
    if (message_arena != submessage_arena) {
      force = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, force, submessage_arena);
    }
    _has_bits_[0] |= 0x00000001u;
  } else {
    _has_bits_[0] &= ~0x00000001u;
  }
  force_ = force;
  // @@protoc_insertion_point(field_set_allocated:gazebo.msgs.Wrench.force)
}

// required .gazebo.msgs.Vector3d torque = 2;
inline bool Wrench::_internal_has_torque() const {
  bool value = (_has_bits_[0] & 0x00000002u) != 0;
  PROTOBUF_ASSUME(!value || torque_ != nullptr);
  return value;
}
inline bool Wrench::has_torque() const {
  return _internal_has_torque();
}
inline const ::gazebo::msgs::Vector3d& Wrench::_internal_torque() const {
  const ::gazebo::msgs::Vector3d* p = torque_;
  return p != nullptr ? *p : *reinterpret_cast<const ::gazebo::msgs::Vector3d*>(
      &::gazebo::msgs::_Vector3d_default_instance_);
}
inline const ::gazebo::msgs::Vector3d& Wrench::torque() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.Wrench.torque)
  return _internal_torque();
}
inline void Wrench::unsafe_arena_set_allocated_torque(
    ::gazebo::msgs::Vector3d* torque) {
  if (GetArena() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(torque_);
  }
  torque_ = torque;
  if (torque) {
    _has_bits_[0] |= 0x00000002u;
  } else {
    _has_bits_[0] &= ~0x00000002u;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:gazebo.msgs.Wrench.torque)
}
inline ::gazebo::msgs::Vector3d* Wrench::release_torque() {
  _has_bits_[0] &= ~0x00000002u;
  ::gazebo::msgs::Vector3d* temp = torque_;
  torque_ = nullptr;
  if (GetArena() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
  return temp;
}
inline ::gazebo::msgs::Vector3d* Wrench::unsafe_arena_release_torque() {
  // @@protoc_insertion_point(field_release:gazebo.msgs.Wrench.torque)
  _has_bits_[0] &= ~0x00000002u;
  ::gazebo::msgs::Vector3d* temp = torque_;
  torque_ = nullptr;
  return temp;
}
inline ::gazebo::msgs::Vector3d* Wrench::_internal_mutable_torque() {
  _has_bits_[0] |= 0x00000002u;
  if (torque_ == nullptr) {
    auto* p = CreateMaybeMessage<::gazebo::msgs::Vector3d>(GetArena());
    torque_ = p;
  }
  return torque_;
}
inline ::gazebo::msgs::Vector3d* Wrench::mutable_torque() {
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.Wrench.torque)
  return _internal_mutable_torque();
}
inline void Wrench::set_allocated_torque(::gazebo::msgs::Vector3d* torque) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArena();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(torque_);
  }
  if (torque) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
      reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(torque)->GetArena();
    if (message_arena != submessage_arena) {
      torque = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, torque, submessage_arena);
    }
    _has_bits_[0] |= 0x00000002u;
  } else {
    _has_bits_[0] &= ~0x00000002u;
  }
  torque_ = torque;
  // @@protoc_insertion_point(field_set_allocated:gazebo.msgs.Wrench.torque)
}

// optional .gazebo.msgs.Vector3d force_offset = 3;
inline bool Wrench::_internal_has_force_offset() const {
  bool value = (_has_bits_[0] & 0x00000004u) != 0;
  PROTOBUF_ASSUME(!value || force_offset_ != nullptr);
  return value;
}
inline bool Wrench::has_force_offset() const {
  return _internal_has_force_offset();
}
inline const ::gazebo::msgs::Vector3d& Wrench::_internal_force_offset() const {
  const ::gazebo::msgs::Vector3d* p = force_offset_;
  return p != nullptr ? *p : *reinterpret_cast<const ::gazebo::msgs::Vector3d*>(
      &::gazebo::msgs::_Vector3d_default_instance_);
}
inline const ::gazebo::msgs::Vector3d& Wrench::force_offset() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.Wrench.force_offset)
  return _internal_force_offset();
}
inline void Wrench::unsafe_arena_set_allocated_force_offset(
    ::gazebo::msgs::Vector3d* force_offset) {
  if (GetArena() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(force_offset_);
  }
  force_offset_ = force_offset;
  if (force_offset) {
    _has_bits_[0] |= 0x00000004u;
  } else {
    _has_bits_[0] &= ~0x00000004u;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:gazebo.msgs.Wrench.force_offset)
}
inline ::gazebo::msgs::Vector3d* Wrench::release_force_offset() {
  _has_bits_[0] &= ~0x00000004u;
  ::gazebo::msgs::Vector3d* temp = force_offset_;
  force_offset_ = nullptr;
  if (GetArena() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
  return temp;
}
inline ::gazebo::msgs::Vector3d* Wrench::unsafe_arena_release_force_offset() {
  // @@protoc_insertion_point(field_release:gazebo.msgs.Wrench.force_offset)
  _has_bits_[0] &= ~0x00000004u;
  ::gazebo::msgs::Vector3d* temp = force_offset_;
  force_offset_ = nullptr;
  return temp;
}
inline ::gazebo::msgs::Vector3d* Wrench::_internal_mutable_force_offset() {
  _has_bits_[0] |= 0x00000004u;
  if (force_offset_ == nullptr) {
    auto* p = CreateMaybeMessage<::gazebo::msgs::Vector3d>(GetArena());
    force_offset_ = p;
  }
  return force_offset_;
}
inline ::gazebo::msgs::Vector3d* Wrench::mutable_force_offset() {
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.Wrench.force_offset)
  return _internal_mutable_force_offset();
}
inline void Wrench::set_allocated_force_offset(::gazebo::msgs::Vector3d* force_offset) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArena();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(force_offset_);
  }
  if (force_offset) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
      reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(force_offset)->GetArena();
    if (message_arena != submessage_arena) {
      force_offset = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, force_offset, submessage_arena);
    }
    _has_bits_[0] |= 0x00000004u;
  } else {
    _has_bits_[0] &= ~0x00000004u;
  }
  force_offset_ = force_offset;
  // @@protoc_insertion_point(field_set_allocated:gazebo.msgs.Wrench.force_offset)
}

#ifdef __GNUC__
  #pragma GCC diagnostic pop
#endif  // __GNUC__

typedef boost::shared_ptr<gazebo::msgs::Wrench> WrenchPtr;
// @@protoc_insertion_point(namespace_scope)

}  // namespace msgs
}  // namespace gazebo

typedef const boost::shared_ptr<gazebo::msgs::Wrench const> ConstWrenchPtr;
// @@protoc_insertion_point(global_scope)

#include <google/protobuf/port_undef.inc>
#endif  // GOOGLE_PROTOBUF_INCLUDED_GOOGLE_PROTOBUF_INCLUDED_wrench_2eproto
